==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/console.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ConsolePlugin</name>
    <message>
        <source>XML Console</source>
        <translation>XML Konsole</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>Konsole</translation>
    </message>
    <message>
        <source>Allows to view XML stream between the client and server</source>
        <translation>Erlaubt das Anzeigen eines XML Streams zwischen dem Client und dem Server</translation>
    </message>
    <message>
        <source>Default Context</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConsoleWidget</name>
    <message>
        <source>&lt;All Streams&gt;</source>
        <translation>&lt;Alle Streams&gt;</translation>
    </message>
    <message>
        <source>XML Console - %1</source>
        <translation>XML Konsole - %1</translation>
    </message>
    <message>
        <source>Start sending user stanza...</source>
        <translation></translation>
    </message>
    <message>
        <source>Stanza is not well formed.</source>
        <translation></translation>
    </message>
    <message>
        <source>XML is not well formed.</source>
        <translation></translation>
    </message>
    <message>
        <source>New Context</source>
        <translation></translation>
    </message>
    <message>
        <source>Enter context name</source>
        <translation></translation>
    </message>
    <message>
        <source>User stanza sent.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConsoleWidgetClass</name>
    <message>
        <source>XML Console</source>
        <translation>XML Konsole</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Stream:</source>
        <translation>Stream:</translation>
    </message>
    <message>
        <source>Condition:</source>
        <translation>Bedingung:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Available context:</source>
        <translation>Verfügbarer Kontext:</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>Konsole</translation>
    </message>
    <message>
        <source>Word wrap</source>
        <translation>Zeilenumbruch</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Highlight XML</source>
        <translation></translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/console.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ConsolePlugin</name>
    <message>
        <source>XML Console</source>
        <translation>XML Konsole</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>Konsole</translation>
    </message>
    <message>
        <source>Allows to view XML stream between the client and server</source>
        <translation>Erlaubt das Anzeigen des XML Datenstroms zwischen dem Client und dem Server</translation>
    </message>
    <message>
        <source>Default Context</source>
        <translation>Standard Kontext</translation>
    </message>
</context>
<context>
    <name>ConsoleWidget</name>
    <message>
        <source>&lt;All Streams&gt;</source>
        <translation>&lt;Alle Datenströme&gt;</translation>
    </message>
    <message>
        <source>XML Console - %1</source>
        <translation>XML Konsole - %1</translation>
    </message>
    <message>
        <source>Start sending user stanza...</source>
        <translation>Starte das senden des Anwender Packetes ...</translation>
    </message>
    <message>
        <source>Stanza is not well formed.</source>
        <translation>Packet ist nicht richtig formatiert.</translation>
    </message>
    <message>
        <source>XML is not well formed.</source>
        <translation>XML ist nicht richtig formatiert.</translation>
    </message>
    <message>
        <source>New Context</source>
        <translation>Neuer Kontext</translation>
    </message>
    <message>
        <source>Enter context name</source>
        <translation>Kontextname eingeben</translation>
    </message>
    <message>
        <source>User stanza sent.</source>
        <translation>Anwender Packet gesendet.</translation>
    </message>
</context>
<context>
    <name>ConsoleWidgetClass</name>
    <message>
        <source>XML Console</source>
        <translation>XML Konsole</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Stream:</source>
        <translation>Datenstrom:</translation>
    </message>
    <message>
        <source>Condition:</source>
        <translation>Bedingung:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Available context:</source>
        <translation>Verfügbarer Kontext:</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>Konsole</translation>
    </message>
    <message>
        <source>Word wrap</source>
        <translation>Zeilenumbruch</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Highlight XML</source>
        <translation>XML hervorheben</translation>
    </message>
</context>
</TS>
